/* ======================================================

  T.O.C. [table of contents]

  01. Remove H3 focus
  02. Load the news-feed
  03. Parse the news-source
  04. Parse the news-article
  05. Show the thumbnails
  06. Show archived entries

====================================================== */

var $app__news, $app__source, $app__news_data, $app__sources, $app__article, $app__articles, $app__articles_pinned, $app__article_comments, $app__archive_treshold, $app__archive_set, $app__archive_elastique;
var $app__archive_delay = $app__archive_delay_tmp = 500;

;(function ( $ ) { try {

/* ######################################################
  01. Remove focus after clicking on article-items
###################################################### */

$( 'body' ).on( 'click', 'h3[data-toggle=collapse]', function( $app__event ) {

  try {

    $app__event.preventDefault();

    $( this ).closest( 'li' ).toggleClass( 'excerpt' ).end().blur();

  } catch ( $app__error ) {

    app__error( 'app__feed#01', 2, $app__error );

  }

});

/* ######################################################
  02. Load the news-feed
###################################################### */

window.app__news_load = function app__news_load() {

  try {

    var $app__api = 'feed';
    $app__url = $app__settings[ 'local' ][ 'api' ] + $app__api;

    app__cmd( 'app__feed : loading > ' + $app__url );

    $.ajax({

      method: 'get',
      url: $app__url,
      cache: false,
      dataType: 'text',
      complete: function() {

/* 2DO */

      },
      success: function( $app__response, $text_status, $xhr ) {

        app__progress( 75 );

        try {

          $app__news = JSON.parse( $app__response );
        
        } catch( $app__error ) {

          app__error( 'app__feed#02A', 2, $app__error );
    
        }

        app__weather_parse();
        app__sources_parse();

        app__cmd( 'app__feed : feed loaded', 1 );

      },
      error: function( $app__xhr, $text_status, $error ) {

        app__error( 'app__feed#02B', 2, JSON.stringify( $app__xhr ) );

      }

    });

  } catch( $app__error ) {

    app__error( 'app__feed#02C', 2, $app__error );

  }

}

/* ######################################################
  03. Parse the news [-sources]
###################################################### */

function app__sources_parse() {

  var $app__screen = $( '#app__news' );

  $app__news_data = '';
  $app__sources = $app__article_comments = 0;
  
  try {

/* -----------------------------------------------------
  Fetch all news-sources
----------------------------------------------------- */
    
    if ( $app__news.hasOwnProperty( 'content' ) ) {

      for ( $app__i = 0; $app__i < $app__news[ 'content' ].length; $app__i++ ) {

        $app__source = [];

        $app__source[ 'title' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'meta' ][ 0 ][ 'title' ];
        $app__source[ 'id' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'meta' ][ 0 ][ 'id' ];
        $app__source[ 'icon' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'meta' ][ 0 ][ 'icon' ];
        $app__source[ 'src' ] = app__format_number( parseInt( $app__news[ 'content' ][ $app__i ][ 'data' ][ 'meta' ][ 0 ][ 'src' ] ) );
        $app__source[ 'kill' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'meta' ][ 0 ][ 'kill' ];

        $app__kill = false;

        if ( typeof $app__source[ 'kill' ] !== 'undefined' && $app__source[ 'kill' ] !== null ) {

          if ( parseInt( $app__source[ 'kill' ] ) === 1 ) {

            $app__kill = true;

          }

        }

/* Check if news-source is valid */

        if ( $app__source[ 'title' ].length > 0 && $app__kill === false ) {

          $app__sources++;

          $( '#navbar-nav ol:eq( 0 )' ).append( '<li class="nav-item list-inline-item text-uppercase m-0"><a href="#app__source_' + $app__source[ 'src' ] + '" class="nav-link btn btn-sm btn-dark btn-brand-dark border-0 px-1 py-2"><span>' + $app__source[ 'icon' ] + '</span><small>' + $app__source[ 'id' ] + '</small></a></li>' );

          $app__news_data += '<ol class="list-unstyled" id="app__source_' + $app__source[ 'src' ] + '" data-src="' + $app__source[ 'src' ] + '">';
          $app__news_data += '<li><h2 class="bg-dark text-light text-uppercase text-center px-3 py-4 mb-4 mt-0 shadow"><b>' + $app__source[ 'title' ] + '</b></h2></li>';

/* -----------------------------------------------------
  When valid -> fetch all articles
----------------------------------------------------- */

/* Check if archive-treshold is set */

          $app__archive_treshold = -1;
          $app__archive_set = -1;

            if ( $app__settings[ 'remote' ][ 'ini' ][ 0 ][ 'status' ].hasOwnProperty( 'archive' ) ) {

              var $app__archive_treshold_tmp = parseInt( $app__settings[ 'remote' ][ 'ini' ][ 0 ][ 'status' ][ 'archive' ] );

              if ( $.isNumeric( $app__archive_treshold_tmp ) ) {

                $app__archive_treshold = $app__archive_treshold_tmp;

              }

            }

/* Fetch every article and parse it [when archive-treshold allows it] */

          $app__articles = 0;
          $app__article = [];
          $app__articles_pinned = [];

          if ( $app__news[ 'content' ][ $app__i ][ 'data' ].hasOwnProperty( 'items' ) ) {

            for ( $app__x = 0; $app__x < $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ].length; $app__x++ ) {

              app__articles_parse();

            }

          }

/* Reset the pinned-article array [memory clean-up] */

          $app__articles_pinned = [];

/* Show warning when no articles are fetched for this source */

          if ( $app__articles === 0 ) {

            $app__news_data += '<div class="shadow alert alert-warning mx-4 mb-5">' + $app__text[ 'string' ][ 2 ] + '</div>';

          }

          $app__news_data += '</ol>';

        }

      } 

    }

/* Remove existing scrollspy [memory leak] */

    $( 'body' ).scrollspy( 'dispose' );

/* Fire the scrollspy */
    
    var $app__offset = 100;

    if ( typeof $app__win_h !== 'undefined' && $app__win_h !== null ) {
      
      if ( !isNaN( $app__win_h ) ) {

        var $app__offset_tmp = Math.floor( parseInt( $app__win_h ) / 3 );

        if ( $app__offset_tmp > $app__offset ) {

          $app__offset = $app__offset_tmp;

        }

      }

    }

    $( 'body' ).scrollspy( {

      offset: $( 'header .navbar' ).outerHeight( true ) + $app__offset,
      target: '#navbar-nav'
    
    } );

    $( window ).on( 'activate.bs.scrollspy', function () {

      var $app__source_active = $( '#navbar-nav ol > li a[href*=app__source_].active' ).attr( 'href' );

      $( '#app__news ol.active' ).removeClass( 'active' );
      $( '#app__news ' + $app__source_active ).addClass( 'active' );
    
    });

/* Show warning when no news-sources are fetched at all */

      if ( $app__sources === 0 ) {

        $app__news_data = '<div class="shadow alert alert-warning">' + $app__text[ 'string' ][ 1 ] + '</div>';

        $( '#navbar-nav ol:eq(0)' ).append( '<li class="nav-item list-inline-item text-uppercase m-0 invisible"><a href="#" class="nav-link btn btn-sm btn-dark btn-brand-dark border-0 px-1 py-2">&nbsp;<br><small>&nbsp;</small></a></li>' );

      }

    $app__screen.html( $app__news_data );

/* #dMOTED | MAYBE DEPRECATED > remove any duplicate pinned articles afterwards 2#2 [pinned article BELOW the feed] */

    $( 'ol[id*=app__source_] li.pin' ).each( function() {

      $( 'ol[id*=app__source_] li[data-guid=' + $( this ).data( 'guid' ) + ']:not(.pin)' ).remove();

    });

/* Update the stats in the footer -> $app__sources | $app__articles | $app__article_comments */

    $( '[data-stats=sources]' ).text( parseInt( $( 'ol[id*=app__source_0]' ).length ) + ' ' + $app__text[ 'string' ][ 61 ] );
    $( '[data-stats=articles]' ).text( parseInt( $( '[id*=app__source_0] > li > h3' ).length ) + ' ' + $app__text[ 'string' ][ 62 ] );
    $( '[data-stats=comments]' ).text( parseInt( $app__article_comments ) + ' ' + $app__text[ 'string' ][ 70 ] );

    app__progress( 100 );

  } catch ( $app__error ) {

    app__error( 'app__feed#03', 2, $app__error );

  }

}

/* ######################################################
  04. Parse the news [-article]
###################################################### */

function app__articles_parse() {

  try {

    $app__article[ 'article' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ][ $app__x ][ 'description' ];

/* Check if article is valid */

    if ( $app__article[ 'article' ].length > 0 ) {

/* Define the headers-class, first article is different */

      var $app__article_class = $app__articles > 0 ? 'border-top pt-3' : 'featured';

/* -----------------------------------------------------
  Article is valid, fetch the content
----------------------------------------------------- */

      $app__article[ 'title' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ][ $app__x ][ 'title' ];
      $app__article[ 'date' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ][ $app__x ][ 'pubDate' ];
      $app__article[ 'guid' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ][ $app__x ][ 'guid' ];
      $app__article[ 'link' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ][ $app__x ][ 'link' ];
      $app__article[ 'id' ] = app__format_number( parseInt( $app__articles + 1 ) );
      $app__article[ 'more' ] = $app__article[ 'article' ].length > 100 ? '<small class="text-muted"> ' + $app__text[ 'string' ][ 3 ] + '</small>' : '';
      $app__article[ 'image' ] = $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ][ $app__x ][ 'image' ];
      $app__article[ 'comments' ] = $app__news[ 'comments' ][ 0 ][ 'reactions' ][ $app__article[ 'guid' ] ];

/* Check if articled is pinned */

      var $app__article_pinned = ( $app__news[ 'content' ][ $app__i ][ 'data' ][ 'items' ][ $app__x ].hasOwnProperty( 'pinned' ) ) ? 1 : -1;
      var $app__article_pinned_class = '';
      var $app__article_pinned_icon = '';

        if ( $app__article_pinned === 1 ) {

          $app__article_pinned_icon = '<i class="zmdi zmdi-star text-muted text-brand d-inline-block mr-2"></i>';
          $app__article_pinned_featured = '<span class="pin mb-2 mb-md-0">- ' + $app__text[ 'string' ][ 55 ] + ' -</span> <br class="d-md-none"> ';
          $app__article_pinned_regular = '<span class="pin">- ' + $app__text[ 'string' ][ 55 ] + ' -</span> ';
          $app__article_pinned_class = $app__articles === 0 ? $app__article_pinned_featured : $app__article_pinned_regular;
          $app__article_class += ' pinned';
 
/* Allow one more article 'before' the archive treshold is reached (elastique treshold) */

          $app__archive_elastique = -1;

          if ( $app__settings[ 'remote' ][ 'ini' ][ 0 ][ 'status' ].hasOwnProperty( 'elastique' ) ) {

            var $app__archive_elastique_tmp = parseInt( $app__settings[ 'remote' ][ 'ini' ][ 0 ][ 'status' ][ 'elastique' ] );

            if ( $.isNumeric( $app__archive_elastique_tmp ) ) {

              $app__archive_elastique = $app__archive_elastique_tmp;

            }

          }

          if ( $app__archive_elastique !== -1 ) {

            $app__archive_treshold++;

          }

/* #dMOTED | MAYBE DEPRECATED > prevent any future duplicate articles to be rendered 1#2 [pinned article ABOVE the feed] */
          
          $app__articles_pinned.push( $app__article[ 'guid' ] );

        } else {

          if ( $.inArray( $app__article[ 'guid' ], $app__articles_pinned ) !== -1 ) {

            return;
 
         }
  
        }

/* Show | set the archive-barrier [divider] */

        if ( $app__articles === $app__archive_treshold && $app__archive_set !== 1 ) {
          
          $app__archive_set = 1;
          $app__news_data += '<li class="border-top pt-3 text-center archive"><button type="button" class="btn btn-outline-dark cursor-pointer mt-2 mb-3 px-4" data-action="archive">' + $app__text[ 'string' ][ 69 ] + '</button></li>';

        }

/* -----------------------------------------------------
  When treshold is not reached - build the article
----------------------------------------------------- */

      $app__articles++;

/* Check if featured image is available */

      $app__article[ 'image' ] = $app__article[ 'image' ] !== '-1' ? $app__article[ 'image' ] : false;

      if (

        $app__article[ 'image' ] !== false &&
        typeof $app__article[ 'image' ] !== 'undefined'
        && $app__article[ 'image' ] !== null &&
        $app__settings[ 'user' ][ 'hide_images' ] !== true

      ) {
              
          $app__image_src = $app__article[ 'image' ];
          $app__image_title = '';
          
            if ( $app__settings[ 'local' ][ 'debug' ] === true ) {

              $app__image_title = $app__image_src;
              $app__image_title = ( $app__image_api_xs === '-1' ? '[ local ] ' : '[ remote ] ' ) + $app__image_title;
              $app__image_title = ' title="' + $app__image_title + '"';
    
            }

          $app__article_image = '<figure data-thumbnail="' + $app__image_src + '"' + $app__image_title + ' class="position-absolute rounded thumbnail border bg-light loading"></figure>';
          $app__article_class += ' image';

        } else {

          $app__article_image = '';

        }

/* Check if comments are available for this article */

      var $app__article_comments_button = '<button type="button" class="btn btn-secondary btn-brand border-0 mb-4" data-action="comment">' + $app__text[ 'string' ][ 13 ] + '</button>';
      var $app__article_comments_icon = '';

        if ( $app__article[ 'comments' ] > 0 ) {

/* Initialize total amount of comments | save totals for later usage (statistics) */

          $app__article_comments += $app__article[ 'comments' ];

          $app__article_comments_button = '<button type="button" class="btn btn-secondary btn-brand border-0 mb-4" data-action="comments">' + $app__text[ 'string' ][ 5 ] + '</button>';

          $app__article_comments_icon = '<i class="zmdi zmdi-comment text-muted text-brand position-relative d-inline-block mr-2"><b class="text-light position-absolute">' + $app__article[ 'comments' ] + '</b></i>';

        }

/* Check if article is already read */

        if ( $.inArray( $app__article[ 'guid' ], $app__settings[ 'list' ][ 'articles' ] ) !== -1 ) {

           $app__article_class += ' read';

        }

/* Check if article contains user-comment */

      var $app__commented = app__in_array( $app__settings[ 'list' ][ 'commented' ], $app__article[ 'guid' ] );

        if ( $app__commented !== -1 ) {

          $app__article_comments_icon += '<i class="zmdi zmdi-face text-muted text-brand d-inline-block mr-2"></i>';

/* Check if new comments are available */
          
          var $app__comments = 1;

          if ( $app__commented.indexOf( '|' ) !== -1 ) {

            $app__comments = parseInt( $app__commented.substr( $app__commented.indexOf( '|' ) + 1 ) );

            if ( $app__article[ 'comments' ] > $app__comments ) {

              $app__article_class += ' comments-new';

            }

          }

        }

        if ( $app__article_class.length ) {

          $app__article_class = ' class="' +  $app__article_class.trim() + '"';

        }

/* Show tooltip for first article in first source only */

      $app__article_tooltip = ( $app__i + $app__x === 0 ) ? ' data-tip="1" data-toggle="tooltip" data-placement="top" data-trigger="manual"' : '';

/* Create the entry */

      $app__news_data += '<li data-guid="' + $app__article[ 'guid' ] + '" data-link="' + $app__article[ 'link' ].replace(/["']/g, '') + '" ' + $app__article_class + $app__article_tooltip + '>';

/* Create the headline */

      $app__news_data += '<h3' + ( $app__settings[ 'local' ][ 'debug' ] === true ? ' title="' + ( $app__articles < 10 ? '0' + $app__articles : $app__articles ) + ' # ' + $app__article[ 'guid' ] + '"' : '' ) + ' class="cursor-pointer collapsed pb-3 mb-0" data-toggle="collapse" data-target="#article_' + $app__source[ 'src' ] + '_' + $app__article[ 'id' ] + '">' ;

/* Create the featured image [if any] and comment icon[s] */

      $app__news_data += $app__article_image + $app__article_pinned_icon + $app__article_comments_icon + $app__article_pinned_class + $app__article[ 'title' ] + '</h3>';

/* Create the article and buttons [inside a collapse] */

      $app__news_data += '<div class="collapse" id="article_' + $app__source[ 'src' ] + '_' + $app__article[ 'id' ] + '">';

/* Bookmark */

      $app__news_data += '<div class="row mb-3"><div class="col-6"><small class="text-secondary cursor-pointer link-secondary btn-bookmark" data-action="bookmark"><i class="zmdi zmdi-star mr-2"></i><span>' + $app__text[ 'string' ][ 73 ] + '</span></small></div>';

/* Share article */

      $app__news_data += '<div class="col-6 text-right"><div class="dropdown btn-share"><small class="text-secondary link-secondary cursor-pointer" data-toggle="dropdown" data-display="static"><i class="zmdi zmdi-share mr-2"></i>' + $app__text[ 'string' ][ 15 ] + '</small><div class="dropdown-menu dropdown-menu-right text-right py-1 shadow"><small class="dropdown-item cursor-pointer text-dark" data-action="share-whatsapp">' + $app__text[ 'string' ][ 40 ] + '<i class="zmdi zmdi-whatsapp ml-2"></i></small><small class="dropdown-item cursor-pointer text-dark" data-action="share-twitter">' + $app__text[ 'string' ][ 42 ] + '<i class="zmdi zmdi-twitter ml-2"></i></small><small class="dropdown-item cursor-pointer text-dark" data-action="share-facebook">' + $app__text[ 'string' ][ 43 ] + '<i class="zmdi zmdi-facebook ml-2"></i></small><small class="dropdown-item cursor-pointer text-dark" data-action="share-email">' + $app__text[ 'string' ][ 39 ] + '<i class="zmdi zmdi-email ml-2"></i></small>' + ( $app__settings[ 'local' ][ 'debug' ] === true ? '<small class="dropdown-item pl-0 bg-secondary"><a href="' + $app__article[ 'link' ] + '" target="_blank" class="pl-0 d-block text-white">[debug]<i class="zmdi zmdi-link ml-2"></i></a></small>' : '' ) + '</div></div></div></div>';
      
/* The article [prefixed by the date] */

      $app__news_data += '<article class="pb-4 clear-fix"><div class="article"><small class="text-secondary pr-2 mr-2 text-date">' + $app__article[ 'date' ] + '</small> '+ $app__article[ 'article' ] + $app__article[ 'more' ] + '</div></article>';

/* The buttons */

      $app__news_data += $app__article_comments_button;

      $app__news_data += '<button type="button" class="btn btn-dark btn-brand-dark border-0 mb-4 float-right" data-action="open">' + $app__text[ 'string' ][ 8 ] + '</button>';

/* Save reference for most populair articles */
    
      app__overview_populair_add( $app__article[ 'guid' ], $app__article[ 'comments' ] );

/* Close the entry */

      $app__news_data += '</li>';
      $app__article = [];

    }

  } catch ( $app__error ) {

    app__error( 'app__feed#04', 2, $app__error );

  }

}

/* ######################################################
  05. Show thumbnails a-sync
###################################################### */

window.app__thumbnails_parse = function app__thumbnails_parse( $app__parse_list ) {

  try {

    var $app__api = 'image';

/* Parse thumbs from specific [archived] list, or parse all [default] */

    var $app__thumbnails_loaded = 0;
    var $app__thumbnails_total = $app__parse_list === -1 ? $( 'li:visible.image figure.thumbnail.loading' ).length : -1;

    var $app__parse_list = $app__parse_list === -1 ? '' : 'ol[data-src=' + $app__parse_list + '] ';

    $( $app__parse_list + 'li:visible.image figure.thumbnail.loading' ).each( function() {

      var $app__image_guid = $( this ).attr( 'data-thumbnail' );
      var $app__image_src = parseInt( $( this ).closest( 'ol' ).data( 'src' ) );
      var $app__image_url = '...';

/* Use local image-api [fallback] */

      if ( $app__image_api_xs === '-1' ) {

        $app__image_url = $app__settings[ 'local' ][ 'api' ] + $app__api + '&src=' + $app__image_src + '&url=' + $app__image_guid;

/* Use third-party image-api [default] */        

      } else {

        $app__image_url = $app__image_guid;

      }

      $( '<img/>' ).attr( 'src', $app__image_url ).on( 'load', function() {
        
          if ( $app__parse_list === '' ) {

            $app__thumbnails_loaded++;

          }

        $( this ).remove();
        $app__figure = $( 'li:visible.image figure.thumbnail[data-thumbnail="' + $app__image_guid + '"]' );
        $app__figure.removeClass( 'border bg-light loading' ).css( {'background-image' : 'url("' + $app__image_url + '")'} ).removeAttr( 'data-thumbnail' );

/* Attach event after loading all the thumbnails */

        if ( $app__thumbnails_loaded === $app__thumbnails_total ) {

// 2DO

        }

      });

    });

  } catch ( $app__error ) {

    app__error( 'app__feed#05', 2, $app__error );

  }

}

/* ######################################################
  06. Show the archived entries in the list
###################################################### */

$( 'body' ).on( 'click', '[data-action=archive]', function( $app__event ) {

  try {

    $app__event.preventDefault();

    var $app__archive_button = $( this );
    var $app__archive_list = $app__archive_button.closest( 'ol' ).data( 'src' );

    $app__archive_button.fadeOut( $app__archive_delay, function() {

      $app__archive_button.closest( '.archive' ).remove();

      setTimeout( function() {

        app__thumbnails_parse( $app__archive_list );

      }, $app__archive_delay );

    } );
    
    $app__archive_delay = $app__archive_delay_tmp;

  } catch ( $app__error ) {

    app__error( 'app__feed#06', 2, $app__error );

  }

} );

/* -----------------------------------------------------
  Catch me if you can
----------------------------------------------------- */

  app__cmd( 'app__feed : script loaded' );

} catch ( $app__error ) {

  app__error( 'app__feed#00', 1, $app__error.message );

} }(jQuery));