/* ======================================================

  T.O.C. [table of contents]

  01. Update personal list
  02. Set bookmark
  03. Get bookmarks
  04. Set comment
  05. Get comments

====================================================== */

;(function ( $ ) { try {

/* ######################################################
  01. Update list
###################################################### */

window.app__personal_list = function app__personal_list( $app__personal_list, $app__personal_entry ) {

  try {

    var $app__personal_listsize = $app__settings[ 'local' ][ 'list' ];            /* Save maximum listsize */
    $app__settings[ 'local' ][ 'list' ] = $app__settings[ 'local' ][ 'list-xs' ]; /* Shrink maximum listsize */
    app__list_set( $app__personal_list, $app__personal_entry );                   /* Update the list (minimum size) */
    $app__settings[ 'local' ][ 'list' ] = $app__personal_listsize;                /* Restore listsize to maximum */

  } catch( $app__error ) {

    app__error( 'app__personal#01', 16, $app__error );

  }

}
  
/* ######################################################
  02. Add a bookmark
###################################################### */

$( 'body' ).on( 'click', '[data-action=bookmark]', function( $app__event ) {
  
  try {
  
    $app__event.preventDefault();
    app__personal_bookmarks_set( $( this ) );

  } catch( $app__error ) {

    app__error( 'app__personal#02A', 16, $app__error );

  }

} );

function app__personal_bookmarks_set( $app__personal_bookmark ) {

  try {

    var $app__personal_guid = $app__personal_bookmark.closest( 'li' ).data( 'guid' );

    app__personal_list( 'personal-bookmarks', $app__personal_guid );

    if ( !$( '#app__personal.animate_bounce' ).length ) {

      $( '#app__personal' ).addClass( 'animate_bounce' );
      
      setTimeout( function() {

        $( '#app__personal' ).removeClass( 'animate_bounce' );

      }, 2500 );

    }

    app__personal_bookmarks_fetch();

  } catch( $app__error ) {

    app__error( 'app__personal#02B', 16, $app__error );

  }

}

/* ######################################################
  03. Get / render bookmarks
###################################################### */

window.app__personal_bookmarks_fetch = function app__personal_bookmarks_fetch() {

  try {

    var $app__personal_bookmark_data = $app__settings[ 'list' ][ 'personal-bookmarks'];
    var $app__personal_bookmark_count = 0;
    var $app__personal_bookmark_list = '';

    $( '#app__personal #personal-bookmarks' ).html( '<li>' + $app__text[ 'string' ][ 75 ].replace( '{#}', $app__settings[ 'local' ][ 'list-xs' ] ) + '</li>' );

    $.each( $app__personal_bookmark_data, function( $app__personal_key, $app__personal_val ) {

/* Get bookmark-entry */

      var $app__personal_bookmark_guid = $app__personal_val;
      var $app__personal_bookmark_guid_el = $( 'li[data-guid="' + $app__personal_bookmark_guid + '"]' );

/* Check if entry is (still) available */

      if ( $app__personal_bookmark_guid_el.length ) {

        var $app__personal_bookmark_title = $app__personal_bookmark_guid_el.find( 'h3' );

/* Check if title is valid */

        if ( $app__personal_bookmark_title.length ) {

/* Render the title, update the count */

          $app__personal_bookmark_title = app__format_string( $app__personal_bookmark_title.html(), 3 );
          $app__personal_bookmark_list += '<li data-scroll-to class="text-truncate-xl cursor-pointer mb-1 mb-md-2" data-populair-guid="' + $app__personal_bookmark_guid + '"><i class="zmdi zmdi-hc-fw zmdi-star position-absolute text-muted"></i> ' + $app__personal_bookmark_title + '</li>';
          $app__personal_bookmark_count++;

        }

      }

    });

/* When bookmarks are valid, show them */

    if ( $app__personal_bookmark_count > 0 ) {

      $( '#app__personal #personal-bookmarks' ).html( $app__personal_bookmark_list );

    }

  } catch( $app__error ) {

    app__error( 'app__personal#03', 16, $app__error );

  }

}

/* ######################################################
  04. Add a comment
###################################################### */

/* See > app__feedback.js > '03. Update and parse the feedback' */

/* ######################################################
  05. Get / render comments
###################################################### */

window.app__personal_comments_fetch = function app__personal_comments_fetch() {

  try {

    var $app__personal_comment_data = $app__settings[ 'list' ][ 'personal-comments'];
    var $app__personal_comment_count = 0;
    var $app__personal_comment_list = '';

    $( '#app__personal #personal-comments' ).html( '<li>' + $app__text[ 'string' ][ 77 ].replace( '{#}', $app__settings[ 'local' ][ 'list-xs' ] ) + '</li>' );

    $.each( $app__personal_comment_data, function( $app__personal_key, $app__personal_val ) {

/* Get comments-entry */

      var $app__personal_comment_entry = $app__personal_val;
      var $app__personal_comment_guid = '';
      var $app__personal_comment_id = '';
      var $app__personal_comment_guid_el = '';

      if ( $app__personal_comment_entry.indexOf( '|' ) !== -1 ) {

        $app__personal_comment_guid = $app__personal_comment_entry.substr( 0, $app__personal_comment_entry.indexOf( '|' ) );
        $app__personal_comment_id = $app__personal_comment_entry.substr( $app__personal_comment_entry.indexOf( '|' ) + 1 );
        $app__personal_comment_guid_el = $( 'li[data-guid="' + $app__personal_comment_guid + '"]' );

      }

/* Check if entry is (still) available */

      if ( $app__personal_comment_guid_el.length ) {

        var $app__personal_comment_title = $app__personal_comment_guid_el.find( 'h3' );

/* Check if title is valid */

        if ( $app__personal_comment_title.length ) {

/* Render the title, update the count */

          $app__personal_comment_title = app__format_string( $app__personal_comment_title.html(), 3 );
          $app__personal_comment_list += '<li data-scroll-to class="text-truncate-xl cursor-pointer mb-1 mb-md-2" data-recent-guid="' + $app__personal_comment_guid + '" data-recent-id="' + $app__personal_comment_id + '"><i class="zmdi zmdi-hc-fw zmdi-comments position-absolute text-muted"></i> ' + $app__personal_comment_title + '</li>';
          $app__personal_comment_count++;

        }

      }

    });

/* When comments are valid, show them */

    if ( $app__personal_comment_count > 0 ) {

      $( '#app__personal #personal-comments' ).html( $app__personal_comment_list );

    }

  } catch( $app__error ) {

    app__error( 'app__personal#05', 16, $app__error );

  }

}

/* -----------------------------------------------------
  Catch me if you can
----------------------------------------------------- */

app__cmd( 'app__personal : script loaded' );

} catch ( $app__error ) {

  app__error( 'app__personal#00', 16, $app__error.message );

} }(jQuery));