/* ======================================================

  T.O.C. [table of contents]

  01. Update the local time
  02. Parse the local time
  03. Parse the last updated time
  03. Parse the weather

====================================================== */

var $app__time_local, $app__time_ini, $app__time_diff;

;(function ( $ ) { try {

/* ######################################################
  01. Update the local time, every minute
###################################################### */

window.app__local_time = function app__local_time() {

  try {

    if ( typeof $app__time_ini !== 'undefined' && $app__time_ini !== null && $.isNumeric( $app__time_ini ) ) {

      $app__time_diff = Math.floor( Date.now() / 1000 ) - $app__time_ini;
      $( '[data-time=local] b:eq( 1 )' ).text( new Date( ( $app__time_local + $app__time_diff ) * 1000 ).toISOString().substr( 11, 5 ) );

    }

  } catch( $app__error ) {

    app__error( 'app__weather_time#01', 6, $app__error );

  }

}

/* Set the time, every minute */

  setInterval( function() {

    app__local_time();

  }, 60000 );

/* ######################################################
  02. Parse and set the local time
###################################################### */

window.app__time_local = function app__time_local() {

  try {

    $app__time_local = parseInt( $app__settings[ 'remote' ][ 'ini' ][ 0 ][ 'time' ][ 'time_local' ] );
    $app__time_ini = Math.floor( Date.now() / 1000 );

/* Show the local-time [where the newssource is located] */

    app__local_time();

  } catch( $app__error ) {

    app__error( 'app__weather_time#02', 6, $app__error );

  }

}

/* ######################################################
  03. Parse and set the last updated time
###################################################### */

window.app__time_updated = function app__time_updated() {

  try {

    var $app__time_update = $app__settings[ 'remote' ][ 'ini' ][ 0 ][ 'time' ][ 'time_update' ];

    $app__time_update = new Date( $app__time_update * 1000 );
    $app__time_update = $app__time_update.toLocaleTimeString( [], { hour: '2-digit', minute: '2-digit', hour12: false } );

      if ( ( ( $app__time_update.match(/:/g) || [] ).length) > 1 ) {

        $app__time_update = $app__time_update.substring( 0, $app__time_update.lastIndexOf( ':' ) );

      }

    $( '[data-time=updated]' ).text( $app__text[ 'string' ][ 60 ].replace( '{#}', $app__time_update ) );

  } catch( $app__error ) {

    app__error( 'app__weather_time#03', 6, $app__error );

  }

}

/* ######################################################
  04. Parse and set the weather
###################################################### */

window.app__weather_parse = function app__weather_parse() {

  try {

/* Get variables */

    var $app__weather_temp = parseInt( $app__news[ 'weather' ][ 0 ][ 'weather' ][ 'temp' ] );
    var $app__weather_clouds = parseInt( $app__news[ 'weather' ][ 0 ][ 'weather' ][ 'clouds' ] );
    var $app__weather_wind = parseFloat( $app__news[ 'weather' ][ 0 ][ 'weather' ][ 'wind' ] );
    var $app__weather_icon = $app__news[ 'weather' ][ 0 ][ 'weather' ][ 'icon' ];

      if ( isNaN( $app__weather_temp ) ) {

        $app__weather_temp = -1;

      }

      if ( isNaN( $app__weather_clouds ) ) {

        $app__weather_clouds = -1;

      }

      if ( isNaN( $app__weather_wind ) ) {

        $app__weather_wind = -1;

      }

      if ( $app__weather_icon === null || $app__weather_icon === '' /* $app__weather_icon.length !== 3 */ ) {

        $app__weather_icon = -1;
  
      }

/*

  {wind.speed} > default: meter/sec | metric: meter/sec | imperial: miles/hour
  
  Ref 1. Windspeed in meters - https://openweathermap.org/current#current_JSON
  Ref 2. Convert to Beaufort - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale

*/

      if ( $app__weather_wind < 1 ) {

        $app__weather_wind = 0;

      } else if ( $app__weather_wind < 1.6 ) {

        $app__weather_wind = 1;

      } else if ( $app__weather_wind < 3.4 ) {

        $app__weather_wind = 2;

      } else if ( $app__weather_wind < 5.5 ) {

        $app__weather_wind = 3;

      } else if ( $app__weather_wind < 8 ) {

        $app__weather_wind = 4;

      } else if ( $app__weather_wind < 10.8 ) {

        $app__weather_wind = 5;

      } else if ( $app__weather_wind < 13.9 ) {

        $app__weather_wind = 6;

      } else if ( $app__weather_wind < 17.2 ) {

        $app__weather_wind = 7;

      } else if ( $app__weather_wind < 20.8 ) {

        $app__weather_wind = 8;

      } else if ( $app__weather_wind < 24.5 ) {

        $app__weather_wind = 9;

      } else if ( $app__weather_wind < 28.5 ) {

        $app__weather_wind = 10;

      } else if ( $app__weather_wind < 32.7 ) {

        $app__weather_wind = 11;

      } else {

        $app__weather_wind = 12;
  
      }

/* Set temperature */

    $( '[data-time=local] b:last-of-type' ).html( $app__weather_temp + '&deg; ' );

/* Set icon */

    $app__weather_code = new Array();

/* Icon > daylight */

    $app__weather_code[ '01d' ] = 'pe-is-w-sun-1-f';
    $app__weather_code[ '02d' ] = 'pe-is-w-partly-cloudy-1-f';
    $app__weather_code[ '03d' ] = 'pe-is-w-mostly-cloudy-2-f';
    $app__weather_code[ '04d' ] = 'pe-is-w-mostly-cloudy-1-f';
    $app__weather_code[ '09d' ] = 'pe-is-w-hail-day-1-f';
    $app__weather_code[ '10d' ] = 'pe-is-w-rain-day-f';
    $app__weather_code[ '11d' ] = 'pe-is-w-thunderstorm-day-1-f';
    $app__weather_code[ '13d' ] = 'pe-is-w-snow-day-2-f';
    $app__weather_code[ '50d' ] = 'pe-is-w-fog-3-f';

/* Icon > moonlight */

    $app__weather_code[ '01n' ] = 'pe-is-w-moon-2-f';
    $app__weather_code[ '02n' ] = 'pe-is-w-partly-cloudy-3-f';
    $app__weather_code[ '03n' ] = 'pe-is-w-mostly-cloudy-2-f';
    $app__weather_code[ '04n' ] = 'pe-is-w-mostly-cloudy-1-f';
    $app__weather_code[ '09n' ] = 'pe-is-w-hail-night-1-f';
    $app__weather_code[ '10n' ] = 'pe-is-w-rain-night-f';
    $app__weather_code[ '11n' ] = 'pe-is-w-thunderstorm-night-1-f';
    $app__weather_code[ '13n' ] = 'pe-is-w-snow-night-2-f';
    $app__weather_code[ '50n' ] = 'pe-is-w-fog-4-f';

/* Icon > fallback for unknown situations */

    $app__weather_code[ '000' ] = 'pe-is-w-thermometer-4-f';

      if ( $app__weather_icon in $app__weather_code === false ) {

        $app__weather_icon = '000';

      }

/* Icon > remove old icon-value */

    $( '[data-time=local] i' ).attr( 'class', function( $app__index, $app__class ){

      return $app__class.replace( /(^|\s)pe-is-w-\S+/g, '' );

    });

/* Icon > set new icon-value */

    $('[data-time=local] i').addClass( $app__weather_code[ $app__weather_icon ] );

/* Text > set textual description of the weather */

    $( '[data-weather]' ).html(

      $app__weather_temp + '&deg; - ' + $app__text[ 'weather' ][ $app__weather_icon ] + '<br>' +
      $app__text[ 'weather' ][ 0 ] + ' ' + $app__weather_clouds + '%<br>' +
      $app__text[ 'weather' ][ 1 ] + ' ' + $app__weather_wind + '/12'

    );

  } catch( $app__error ) {

    app__error( 'app__weather_time#04', 6, $app__error );

  }

}

/* -----------------------------------------------------
  Catch me if you can
----------------------------------------------------- */

app__cmd( 'app__weather_time : script loaded' );

} catch ( $app__error ) {

  app__error( 'app__weather_time#00', 6, $app__error.message );

} }( jQuery ));