/* ======================================================

  T.O.C. [table of contents]

  01. Bind software functions to the operating system
  02. Close menu | modal | article on back-key
  03. Check time-difference between app-start and -resume
  04. Open a URL in the system-browser
  05. Show message when offline
  06. Load ad

====================================================== */

/* ######################################################
  01. Bind all API-functions to the device
###################################################### */

function app__core_load() {

  document.addEventListener( 'deviceready', app__core_ready, false );

}

function app__core_ready() {

  document.addEventListener( 'resume', app__resume.bind( this ), false );
  document.addEventListener( 'backbutton', app__backkey, false );

}

;(function ( $ ) { try {

/* ######################################################
  02. Enable some basic functions with the back-key
###################################################### */

if ( $app__settings[ 'local' ][ 'debug' ] === true ) {
  
  $( document ).keyup( function( $app__event ) {

    if ( $app__event.keyCode === 27 ) {

      app__backkey();

    }

  });

}

function app__backkey_unbind() {
  
  clearTimeout( $app__backkey );
  $( '#app__backkey' ).removeClass( 'd-none' ).hide();

}

var $app__backkey;

window.app__backkey = function app__backkey() {

  try {

/* 1#5 > close main-menu first */

    if ( $( '.menu-open' ).length ) {

      app__backkey_unbind();
      $( 'button[data-toggle=offcanvas]' ).trigger( 'click' );

/* 2#5 > ...or close the universal-modal */

    } else if ( $( '.modal-open' ).length ) {

      app__backkey_unbind();
      $( 'button[data-dismiss=modal]' ).trigger( 'click' );

/* 3#5 > ...or close the photo-modal */

    } else if ( $( '.pswp-open' ).length && ( $app__pswp_gallery !== 'undefined' && $app__pswp_gallery !== null ) ) {

      app__backkey_unbind();
      $app__pswp_gallery.close();

/* 3#5 > ...or close personal-menu */

    } else if ( $( '#app__personal.show' ).length ) {

      app__backkey_unbind();
      $( '#app__personal.show' ).trigger( 'click' );

/* 4#5 > nothing left - close the app */

    } else {

/* scroll to top (return to 'start' screen) */

    $( document ).scrollTop( 0 );

/* try to exit */

      if ( $( '#app__backkey:visible' ).length ) {

        app__backkey_unbind();

        try {

          navigator.app.exitApp();    

        } catch ( $app__error ) {

          location.reload();

        }

/* show warning first */

      } else {

        app__backkey_unbind();

        $( '#app__backkey' ).fadeIn( 500, function() {

          $app__backkey = setTimeout( function() {
            
            $( '#app__backkey' ).fadeOut( 500 );

          }, 3500 );

        });

      }

    }

  } catch ( $app__error ) {
  
    app__error( 'app__core#02', 7, $app__error.message );
  
  }

}

/* ######################################################
  03. Check if a forced update is required
###################################################### */

window.app__resume = function app__resume() {

  try {

/* Always update the local-time [where the news-source is located] */

    app__local_time();

/* Check if the app must update the newsfeed */

    $app__refresh_resume = Math.floor( Date.now() / 1000 );
    $app__refresh_difference = Math.round( ( $app__refresh_resume - $app__refresh_start ) / 60 );
    
    if ( ( ( $app__refresh_difference >= $app__settings[ 'local' ][ 'refresh' ] ) ||
           ( $app__settings[ 'local' ][ 'debug' ] === true && $app__ua_android === false ) ) &&
             $app__refresh_allowed === 1 ) {

      $app__refresh_allowed = 0;

      setTimeout( function() {
        
        $app__refresh_tombstoned = 1;

        app__restart();

        app__cmd( 'app__core : app active for #' + $app__refresh_difference + ' min.', 1 );
        app__cmd( 'app__core : tombstone activated for #' + $app__settings[ 'local' ][ 'tombstone' ] + ' secs.', 1 );
  
          setTimeout( function() {
          
            $app__refresh_tombstoned = 0;

            app__cmd( 'app__core : tombstone de-actived after #' + $app__settings[ 'local' ][ 'tombstone' ] + ' secs.', 1 );

          }, $app__settings[ 'local' ][ 'tombstone' ] * 1000 );
  
      }, 1000 );

    } else {

      app__cmd( 'app__core : app active for #' + $app__refresh_difference + ' min.', 1 );

    }

  } catch ( $app__error ) {

    app__error( 'app__core#03', 7, $app__error.message );
    
  }

}
  
/* ######################################################
  04. Open an URL in the browser
###################################################### */

window.app__browse = function app__browse( $app__url, $app__target ) {

  try {
    
    $app__target = $app__target || 1;

/* Default device browser */

    if ( $app__target == 1 ) {

      cordova.InAppBrowser.open( $app__url, '_system' );

/* In-app browser */

    } else if ( $app__target == 2 ) {

      cordova.InAppBrowser.open( $app__url, '_blank', 'location=no,zoom=no,hardwareback=yes' );

/* Open playstore (alternative protocol for Android devices) */

    } else if ( $app__target == 3 ) {

      navigator.app.loadUrl( $app__url, { openExternal: true } );

    }
  
  } catch ( $app__error ) {

    if ( $app__settings[ 'local' ][ 'debug' ] == true ) {

      window.open( $app__url, '_blank', 'location=no' );

    } else {

      app__error( 'app__core#04', 7, $app__error.message );

    }

  }

}

/* ######################################################
  05. Show message when internet is gone
###################################################### */

window.app__offline = function app__offline() {

  try {

    var $app__network = navigator.connection.type;
    var $app__network_states = {};

    $app__network_states[ Connection.UNKNOWN ] = 'unknown';
    $app__network_states[ Connection.ETHERNET ] = 'ethernet';
    $app__network_states[ Connection.WIFI ] = 'wifi';
    $app__network_states[ Connection.CELL_2G ] = '2g';
    $app__network_states[ Connection.CELL_3G ] = '3g';
    $app__network_states[ Connection.CELL_4G ] = '4g';
    $app__network_states[ Connection.CELL ] = 'cell';
    $app__network_states[ Connection.NONE ] = 'none';
    
    app__cmd( 'app__core : connection 3#3 > ' + $app__network_states[ $app__network ], 1 );

    // alert( 'network type : ' + $app__network_states[ $app__network ] );

    if ( $app__network_states[ $app__network ] === 'none' ) {

      app__error( 'app__core#05', 12, 'no network type active' );

    }

  } catch ( $app__error ) {

    app__cmd( 'app__core : connection 3#3 > check skipped on local machine', 1 );

  }

}

/* ######################################################
  06. Show ad
###################################################### */

/* Ref 1. https://github.com/floatinghotpot/cordova-admob-pro/blob/master/test/admob_simple.js */
/* Ref 2. https://developers.google.com/admob/android/test-ads */

$app__ad_dismiss = 1;

window.app__ad_show = function app__ad_show() {

  try {

    var $app__admobid = {

      banner: $app__settings[ 'local' ][ 'ads' ],
      interstitial : $app__settings[ 'local' ][ 'interstitial' ]

    };
    
    if ( AdMob ) {

      AdMob.createBanner( {

        adId: $app__admobid.banner,
        isTesting: $app__settings[ 'local' ][ 'debug' ] ? true : false,
        autoShow: true,
        adSize: 'SMART_BANNER',
        position: AdMob.AD_POSITION.BOTTOM_CENTER,
        overlap: false,
        offsetTopBar: false,
        bgColor: 'black'

      } );

      if ( $app__interstitial > -1 && ( parseInt( $app__settings[ 'user' ][ 'interstitial' ] ) !== $app__interstitial ) ) {

        $app__interstitial_show = 1;
        
        AdMob.prepareInterstitial( {

          adId: $app__admobid.interstitial,
          isTesting: $app__settings[ 'local' ][ 'debug' ] ? true : false,
          autoShow: false
  
        } );

        if ( $app__ad_dismiss === 1 ) {

          $app__ad_dismiss = -1;
          document.addEventListener( 'onAdDismiss', function() {

            try {

              $( '#app__interstitial' ).removeClass( 'fired' );
              $( 'body' ).removeClass( 'no-flow' );

              setTimeout( function() {

                if ( typeof $app__interstitial_entry !== 'undefined' ) {

                  $( 'html, body' ).animate( {

                    scrollTop: Math.floor( $app__interstitial_entry.offset().top - $( '.navbar' ).outerHeight() - 10 )
          
                  }, 0, function() {

                    $app__interstitial_entry.find( 'h3' ).addClass( 'animate_pulse' );

                    setTimeout( function() {

                      $app__interstitial_entry.find( 'h3' ).removeClass( 'animate_pulse' );
                
                    }, 5000 );

                  } );

                }

              }, 1000 );

            } catch ( $app__error ) {

/* nothing */
// app__error( 'app__core#06A', 7, $app__error.message );

            }

          } );

        }

      }

// app__ad_events();

    }

  } catch ( $app__error ) {

/* nothing */
// app__error( 'app__core#06B', 7, $app__error.message );

  }

}

window.app__ad_events = function app__ad_events() {

  document.addEventListener( 'onReceiveAd', function( $app__data ) { app__ad_status( $app__data ); } );
  document.addEventListener( 'onAdFailLoad', function( $app__data ) { app__ad_status( $app__data ); } );
  document.addEventListener( 'onAdLoaded', function( $app__data ) { app__ad_status( $app__data ); } );
  document.addEventListener( 'onAdPresent', function( $app__data ) { app__ad_status( $app__data ); } );
  document.addEventListener( 'onAdLeaveApp', function( $app__data ) { app__ad_status( $app__data ); } );
  document.addEventListener( 'onAdDismiss', function( $app__data ) { app__ad_status( $app__data ); } );
  
}
  
window.app__ad_status = function app__ad_status( $app__data ) {
  
  alert(

    'status : ' + $app__data.error +
    '\n reason : ' + $app__data.reason +
    '\n adNetwork : ' + $app__data.adNetwork +
    '\n adType : ' + $app__data.adType +
    '\n adEvent : ' + $app__data.adEvent

  );
  
}

/* -----------------------------------------------------
  Catch me if you can
----------------------------------------------------- */

app__cmd( 'app__core : script loaded' );

} catch ( $app__error ) {

  app__error( 'app__core#00', 7, $app__error.message );

} }( jQuery ) );