/* ======================================================

  T.O.C. [table of contents]

  01. Variables
  02. Console debugging
  03. Get device dimensions
  04. Show errors
  05. Numbers : add leading zero
  06. Strings : remove script-tags
  07. Modal : actions on -open | -close
  08. Tooltip actions
  09. Create 'loading' button
  10. Toggle function | text of news-buttons
  11. Check internet for every ajax-call
  12. Check if entry is partially available in array
  13. Post basic data for every ajax-call
  14. Fetch image thumbnail from news-entry

====================================================== */

/* ######################################################
  01. Set some cross-script variables
###################################################### */

var $app__win_w, $app__win_h, $app__scroll_pos, $app__modal_speed, $app__url, $app__connection_error = '';

/* At default, there are no connection-errors [see app__initialize.js] and the internalcode is 'app__core_05' [see app__core.js] */

var $app__error_connection = 'app__core#05';

;(function ( $ ) { try {

/* ######################################################
  02. Better debuging in the console
###################################################### */

window.app__cmd = function app__cmd( $app__msg, $app__divider ) {

  if ( window.console && $app__settings[ 'local' ][ 'debug' ] === true ) {

    $app__divider = $app__divider || -1;

    if ( $app__msg === '[clear]' ) {

      console.API;

        if ( typeof console._commandLineAPI !== 'undefined' ) {

          console.API = console._commandLineAPI;
          console.API.clear();

        } else if ( typeof console._inspectorCommandLineAPI !== 'undefined' ) {

          console.API = console._inspectorCommandLineAPI;
          console.API.clear();

        } else if ( typeof console.clear !== 'undefined' ) {

          console.API = console;
          console.API.clear();

        }

    } else if ( $app__msg !== '' ) {

      console.log( '%c[debug] ' + $app__msg, 'background:#242424; color: #a6e22e' );

    }

    if ( $app__divider === 1 ) {

      console.log( '%c----------------------------------------------------------------------------------------------------', 'background:#242424; color: #66d9ef' );

    }

  }

}

/* ######################################################
  03. Set body-class based on device dimensions
###################################################### */

function app__dimensions() {

  $( 'body' ).addClass( 'no-flow' );

    $app__win_w = $( window ).width();
    $app__win_h = $( window ).height();

/* alert( 'width : #' + $app__win_w + 'xp | height : #' + $app__win_h + 'px' ); */

  $( 'body' ).removeClass( 'no-flow' );

  app__cmd( 'app__parent : gui ' + $app__win_w + 'px [width] | ' + $app__win_h + 'px [height]', 1 );

}

$( document ).ready(function(){

  app__cmd( '',  1 );
  app__dimensions();

});

$( window ).on( 'rotate resize', function() {

  app__dimensions();

});

/* ######################################################
  04. Show error
###################################################### */

/* -----------------------------------------------------

  $app__error_code    > unique code for every error ( app__script_name#01 )
  $app__error_text    > user-friendly text (can be share along error-codes)
  $app__error_message > raw error message, not user friendly
  $app__error_report  > report any error to the api

----------------------------------------------------- */

window.app__error = function app__error( $app__error_code, $app__error_text, $app__error_message ) {

/* During development, show the raw error-message */

  if ( $app__settings[ 'local' ][ 'debug' ] === true ) {

    alert( $app__error_code + '\n' + $app__error_message );

/* In production, show an error-notification */

  } else {

    var $app__message_box = $( '.alert-secondary' );
    var $app__error_box = $( '.alert-danger' );
    var $app__error_button = '<br><button type="button" data-action="restart" class="btn btn-danger mt-4">' + $app__text[ 'string' ][ 27 ] + '</button>';

/* Allways show connection errors [see 'app__core.js' > app__core#05] */

      if ( ( !$app__message_box.length && $app__error_box.length ) && ( $app__error_code === $app__error_connection ) ) {

        $app__message_box = $app__error_box;

      }

    $app__message_box
      .removeClass( 'alert-secondary d-none bg-brand-dark text-white' )
      .addClass( 'shadow alert-danger visible position-fixed container' )
      .removeAttr( 'data-error' )
      .attr( 'data-error', $app__error_code )
      .find( 'h3' ).text( $app__text[ 'error' ][ 0 ] )
      .next( 'p' ).html( $app__text[ 'error' ][ $app__error_text ] + $app__error_button + '<hr><small><b>' + $app__error_code + '</b></small>' );

  }

/* -----------------------------------------------------
  See if any errors must be reported
----------------------------------------------------- */

  var $app__error_report = -1;

/* Check if ini is loaded at all [error can be thrown before .ini is loaded] */

    if ( $app__settings[ 'remote' ].hasOwnProperty( 'ini' ) ) {

      $app__error_report = parseInt( $app__settings[ 'remote' ][ 'ini' ][ 0 ][ 'status' ][ 'errorreport' ] );

    }

/* When set to 1, the error must be reported to the api [report connection-errors only once] */

    if ( $app__error_report === 1 && $app__connection_error !== 1 ) {
      
      try {

        var $app__api = 'error';
        var $app__error_url = $app__settings[ 'local' ][ 'api' ] + $app__api;
        var $app__settings_user = '';
        var $app__index = 0;

/* Try to deliver connection-errors once */

          if ( $app__error_code === $app__error_connection ) {

            $app__connection_error = 1;
      
          }

/* Build some debug-information */

          for ( var $app__key in $app__settings[ 'user' ] ) {

            $app__index++;
            var $app__value = $app__settings[ 'user' ][ $app__key ];
            $app__settings_user += ( $app__index == 1 ? '| ' : '' ) + $app__key + ' : "' +  $app__value + '" | ';
        
          }

        var $app__data = {

          app__id: $app__settings[ 'local' ][ 'id' ],
          app__version: $app__settings[ 'local' ][ 'version' ],
          app__url: $app__url,
          app__error_code: $app__error_code,
          app__error_message: $app__error_message,
          app__error_text: $app__text[ 'error' ][ $app__error_text ],
          app__settings_user: $app__settings_user.trim()

        }
        
        app__cmd( 'app__parent : loading > ' + $app__error_url );

        $.ajax({

          method: 'post',
          url: $app__error_url,
          cache: false,
          dataType: 'text',
          data: $app__data,
          complete: function() {
    
/* 2DO */
    
          },
          success: function( $response, $text_status, $xhr ) {
    
            app__cmd( 'app__parent : error reported', 1 );
    
          },
          error: function( $xhr, $text_status, $error ) {

/* Do nothing [prevent error-loop wheh trying to post without internet > connection-error will trigger] */
  
          }
    
        });

      } catch ( $app__error ) {

/* Do nothing [prevent error loop] */

    }

  }

}

/* ######################################################
  05. Add leading zero
###################################################### */

window.app__format_number = function app__format_number( $app__number, $app__number_min ) {

  $app__number_min = $app__number_min || 10;

  $app__number = parseInt( $app__number );

  if ( $app__number < $app__number_min ) {

    $app__number = '0' + $app__number;

  }

  return $app__number;

}

/* ######################################################
  06. Clean-up text-strings
###################################################### */

window.app__format_string = function app__format_string( $app__string, $app__clean_all ) {

  $app__clean_all = $app__clean_all || 1;

  if ( $app__string === 'undefined' || $app__string === null ) {

    return '...';

  } else {

/* CLEAN #1 > remove all tags -> keep contents inside */

    if ( $app__clean_all === 1 ) {

      var $app__string = $app__string.replace( /(<([^>]+)>)/ig, '' );

/* CLEAN #2 > remove only <script> tags -> keep contents inside */

    } else if ( $app__clean_all === 2 )  {

      var $app__string = $app__string.replace( /<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi, '' );

/* CLEAN #3 > remove all tags -> and delete contents inside, also images */

    } else if ( $app__clean_all === 3 )  {

      var $app__string = $app__string.replace( /<([^>]+?)([^>]*?)>(.*?)<\/\1>/ig, '' );
      $app__string = $app__string.replace( /(<([^>]+)>)/ig, '' );

    }

    return ( $app__string.trim() );

  }

}

/* ######################################################
  07. Modals
###################################################### */

/* Prevent scrolling when modal is open */

$app__modal_speed = Math.round( parseFloat( $( '.fade' ).css( 'transition-duration' ) ) * 1000 );

$( '.modal' ).on( 'show.bs.modal', function () {

  if ( $( '.modal-feedback' ).length ) {

    app__namechange();
    app__namecolor();
    $( '.form-feedback #mail' ).val( $app__settings[ 'local' ][ 'no-mail' ] );

  }

  app__no_scroll( 1 );
  
});

window.app__no_scroll = function app__no_scroll( $app__caller ) {

/* SHOW : action on modal- | menu-open [ $app__caller = 1 ] */

  if ( $app__caller === 1  ) {

    $app__scroll_pos = $( document ).scrollTop();
    
    if ( $( '.app__ua_w10m' ).length ) {

      window.scrollTo( 0, 0 );
      $( 'html' ).addClass( 'no-flow' );

    }
    
    app__cmd( 'app__parent : scroll-position #' + $app__scroll_pos + 'px', 1 );

/* HIDE : action on modal- | menu-close [ $app__caller = -1 ] */

  } else {

    if ( $( '.app__ua_w10m' ).length ) {

      $( 'html' ).removeClass( 'no-flow' );
      window.scrollTo( 0, $app__scroll_pos );
  
    }

  }

}

/* -----------------------------------------------------

  Actions on modal-close

  .modal-message   > .notification | .update
  .modal-image     > .featured
  .modal-feedback  > .comment | .mail

----------------------------------------------------- */

$( '.modal' ).on( 'hide.bs.modal', function () {

  setTimeout( function() {
    
/* .modal-feedback > general reset */

    if ( $( '.modal' ).hasClass( 'modal-feedback' ) ) {

        $( 'form.form-feedback #time, form.form-feedback #text, form.form-feedback #mail, form.form-feedback #file, form.form-feedback #item, form.form-feedback #reply, form.form-feedback #level, form.form-feedback input[id*=namepin-]' ).val( '' );
        $( '[data-action=send]' ).removeClass( 'loading disabled' ).text( $app__text[ 'string' ][ 11 ] );
        $( '[required]' ).removeClass( 'error' );
        $( '.resized' ).removeClass( 'resized' );
        $( '.modal' ).find( '.confirm' ).text( '...' );

/* .modal-feedback > comments reset */

      if ( $( '.modal' ).hasClass( 'comment' ) ) {

        if ( $app__feedback_button.length ) {

          $app__feedback_button.removeClass( 'disabled' );
          $app__feedback_button = '';

        }

      }

/* .modal-message > reset */

      } else if ( $( '.modal' ).hasClass( 'modal-message' ) ) {

        $( '.modal' ).find( '.notification, .update' ).text( '...' );

/* .modal-image > reset */

      } else if ( $( '.modal' ).hasClass( 'modal-image' ) ) {

        $( '.modal' ).css( {'background-image': 'none'} );

        if ( $app__image_fullscreen.length ) {

          $app__image_fullscreen.removeClass( 'disabled' );
          $app__image_fullscreen = '';

        }

/* .modal-namepin > reset */

      } else if ( $( '.modal' ).hasClass( 'modal-namepin' ) ) {

        $( '.modal' ).find( '.modal-header' ).show();

      }

/* all .modal > reset */

      app__no_scroll( -1 );

      $( '.modal' ).
        removeClass().
        addClass( 'modal fade' ).
        find( '.modal-title' ).
        text( '...' ).
        removeClass( 'thumb' );

      $( '.modal-body form.form-feedback .form-control' ).prop( 'readonly', false );
      $( '.modal form.form-feedback .form-control, [data-action=namechange]' ).removeClass( 'disabled' );

  }, $app__modal_speed * 3 );

} );

/* ######################################################
  08. Tooltips
###################################################### */

/* Auto-show a [tool-] tip at start of app */

window.app__show_tip = function app__show_tip( $app__tip ) {

  $app__tip = parseInt( $app__tip );

  try {

    if ( $( '[data-tip=' + $app__tip + ']:visible' ).length ) {

      $( '[data-tip=' + $app__tip + ']' ).tooltip( 'show' );

    }

/* Unique class for every tooltip */

    $( '.tooltip.show' ).addClass( 'app__tooltip_' + $app__tip );

/* Add header-class for tooltips in header */

      if ( $( 'header [data-tip=' + $app__tip + ']' ).length ) {

        $( '.tooltip.show' ).addClass( 'app__tooltip_header' );

      }

/* Update 'last seen' tooltip and save it for future reference */

    $app__tip++;
    app__user_set( 'tip', '' + $app__tip );

  } catch( $app__error ) {

    app__error( 'app__parent#01', 4, $app__error );

  }

}

window.app__tooltips = function app__tooltips() {

  try {

/* Remove old tooltip[s] before restart  */

    $( '[data-toggle=tooltip]' ).tooltip( 'dispose' ).attr( 'title', '' );

/* Populate the active tooltip, if any */

    if ( $( '[data-tip="' + $app__settings[ 'user' ][ 'tip' ] + '"]' ).length ) {

      $( '[data-tip="' + $app__settings[ 'user' ][ 'tip' ] + '"]' ).
        attr( 'title', $app__text[ 'tip' ][ 0 ] + ' ' + $app__text[ 'tip' ][ $app__settings[ 'user' ][ 'tip' ] ] ).
        tooltip({

          html: true,
          animation: false
  
        });
  
/* Prepare a [tool-] tip */

      app__show_tip( $app__settings[ 'user' ][ 'tip' ] );

    }

  } catch( $app__error ) {

    app__error( 'app__parent#02', 4, $app__error );

  }

}

/* Delete all tooltips when reading */

$( 'body' ).on( 'click', 'h3[data-toggle=collapse], [data-tip], .tooltip, .navbar-toggler', function() {

  $( '[data-toggle=tooltip]' ).tooltip( 'dispose' );

});

/* ######################################################
  09. Create 'loading' button
###################################################### */

window.app__loading_button = function app__loading_button( $app__button ) {

  $app__button.css( { 'min-width': parseInt( $app__button.outerWidth() ) + 'px' } ).html( '<i class="zmdi zmdi-hourglass animate_spin"></i>' ).addClass( 'disabled' ).blur();

}

/* ######################################################
  10. Toggle news-buttons
###################################################### */

window.app__buttons_toggle = function app__buttons_toggle( $app__article_src, $app__article_guid, $app__caller ) {

  try {

    var $app__button_more = $( 'ol[data-src="' + $app__article_src + '"] li[data-guid="' + $app__article_guid + '"] .btn[data-action=open]' );
    var $app__button_comments = $( 'ol[data-src="' + $app__article_src + '"] li[data-guid="' + $app__article_guid + '"] .btn[data-action=comments]' );
    var $app__button_comment = $( 'ol[data-src="' + $app__article_src + '"] li[data-guid="' + $app__article_guid + '"] .btn[data-action=comment]' );

    if ( $app__caller == 1 ) {

/* Caller #1 [article] : Open <--> Close */

      $app__button_more.attr( 'data-action', 'close' ).html( $app__text[ 'string' ][ 12 ] ).removeClass( 'invisible disabled' );

/* Caller #2 [comments] : show 'More' */

    } else {

      $app__button_more.html( $app__text[ 'string' ][ 8 ] ).removeClass( 'invisible disabled' );

    }

/* Always execute [buttons can be available for both caller#1 and caller#2] */

    if ( $app__button_comments.length ) {

      $app__button_comments.attr( 'data-action', 'comment' ).html( $app__text[ 'string' ][ 13 ] ).removeClass( 'invisible disabled' );

    } else {

      $app__button_comment.removeClass( 'invisible disabled' );

    }

  } catch( $app__error ) {

    app__error( 'app__parent#03', 4, $app__error );

  }

}

/* ######################################################
  11. Check internet with every ajax call
###################################################### */

$( document ).ajaxStart( function() {

  try {

    app__cmd( 'app__parent : connection 1#3 > wait #' + ( $app__refresh_tombstoned === 1 ? $app__settings[ 'local' ][ 'tombstone' ] : 1 ) + ' secs. before checking the status' );

    setTimeout( function() {

      app__cmd( 'app__parent : connection 2#3 > status checked by the ajax call' );

      app__offline();

    }, $app__refresh_tombstoned === 1 ? ( $app__settings[ 'local' ][ 'tombstone' ] * 1000 ) : 1000 );
  
  } catch( $app__error ) {

    app__error( 'app__parent#04', 4, $app__error );

  }
  
});

/* ######################################################
  12. Partial array match
###################################################### */

window.app__in_array = function app__in_array( $app__array, $app__value ) {

  try {

    for ( var $app__index = 0; $app__index < $app__array.length; $app__index++ ) {

      if ( $app__array[ $app__index ].indexOf( $app__value ) > -1 ) {
  
        return $app__array[ $app__index ];

      }
  
    }
    
    return -1;
    
  } catch( $app__error ) {

    app__error( 'app__parent#05', 4, $app__error );

  }

}

/* ######################################################
  13. Post basic data for every ajax-call
###################################################### */

window.app__data = function app__data() {

  try {

    return {

      app__id: $app__settings[ 'local' ][ 'id' ],
      app__version: $app__settings[ 'local' ][ 'version' ],
      app__user: $app__settings[ 'user' ][ 'id' ],
      app__url: $app__url

    };

  } catch( $app__error ) {

    app__error( 'app__parent#06', 4, $app__error );

  }

}

/* ######################################################
  14. Fetch thumbnail from news-entry
###################################################### */

window.app__thumbnail_get = function app__thumbnail_get( $app___thumbnail_el ) {

  try {
  
    if ( $app___thumbnail_el.length ) {

      $app___thumbnail_el = $app___thumbnail_el.find( 'h3 figure' ).css( 'background-image' );
      $app___thumbnail_el = /^url\((['"]?)(.*)\1\)$/.exec( $app___thumbnail_el );
      $app___thumbnail_el = $app___thumbnail_el ? $app___thumbnail_el[ 2 ] : -1;
    
    } else {

      $app___thumbnail_el = -1;

    }

    return $app___thumbnail_el;

  } catch( $app__error ) {

    app__error( 'app__parent#07', 4, $app__error );

  }

}

/* -----------------------------------------------------
  Catch me if you can
----------------------------------------------------- */
  
  app__cmd( '[clear]', 1 );
  app__cmd( 'app__parent : welcome > ' + new Date(), 1 );
  app__cmd( 'app__parent : script loaded' );

} catch ( $app__error ) {

  app__error( 'app__parent#00', 4, $app__error.message );

} }( jQuery ));